import typer
from acemist.print_utils.print_sites import print_list_sites, print_site_details

app = typer.Typer(help="Manage sites.")


@app.command("list")
def list_sites(ctx: typer.Context):
    """List all sites."""
    mist = ctx.obj.mist
    site_data = mist.site_list()
    print_list_sites(site_data)


@app.command("show")
def get_site(
    ctx: typer.Context,
    
):
    """Get details for a specific site."""
    mist = ctx.obj.mist
    site_data = mist.site_get()

    print_site_details(site_data)

